pub enum MoveExecution {
Actions(Vec<MoveUse>),
Script,
None,
}Variants
Actions(Vec<MoveUse>)
Load a vector of actions
Script
Use a script defined in the instance of the object that uses this
None
Placeholder to show that object does not have a defined use yet.
Implementations