pub enum ClientMoveAction {
SetHP(ClientDamage<f32>),
AddStat(BattleStatType, Stage),
Ailment(Option<LiveAilment>),
Cancel(MoveCancel),
Miss,
SetExp(Experience, Level),
Error,
}Variants
SetHP(ClientDamage<f32>)
This contains the percent HP the pokemon was left at, how effective the attack was, and if it was a critical hit. A Pokemon faints when it’s hp is set to 0.0
AddStat(BattleStatType, Stage)
Ailment(Option<LiveAilment>)
Cancel(MoveCancel)
Miss
SetExp(Experience, Level)
Error